@@ -1,15 +1,13 @@
-#ifndef __STAN__AGRAD__FWD__MATRIX__TRACE_QUAD_FORM_HPP__
-#define __STAN__AGRAD__FWD__MATRIX__TRACE_QUAD_FORM_HPP__
+#ifndef STAN__AGRAD__FWD__MATRIX__TRACE_QUAD_FORM_HPP
+#define STAN__AGRAD__FWD__MATRIX__TRACE_QUAD_FORM_HPP
 
 #include <boost/type_traits.hpp>
 #include <stan/math/error_handling/matrix/check_multiplicable.hpp>
 #include <stan/math/error_handling/matrix/check_square.hpp>
 #include <stan/agrad/fwd/matrix/multiply.hpp>
-#include <stan/agrad/rev/matrix/multiply.hpp>
 #include <stan/math/matrix/multiply.hpp>
 #include <stan/math/matrix/transpose.hpp>
 #include <stan/math/matrix/trace.hpp>
-#include <stan/agrad/rev/operators.hpp>
 #include <stan/agrad/fwd/fvar.hpp>
 
 namespace stan {
