@@ -1,5 +1,5 @@
-#ifndef __STAN__AGRAD__REV__FUNCTIONS__BESSEL_FIRST_KIND_HPP__
-#define __STAN__AGRAD__REV__FUNCTIONS__BESSEL_FIRST_KIND_HPP__
+#ifndef STAN__AGRAD__REV__FUNCTIONS__BESSEL_FIRST_KIND_HPP
+#define STAN__AGRAD__REV__FUNCTIONS__BESSEL_FIRST_KIND_HPP
 
 #include <stan/agrad/rev/var.hpp>
 #include <stan/agrad/rev/internal/vv_vari.hpp>
