@@ -1,5 +1,5 @@
-#ifndef __STAN__AGRAD__REV__FUNCTIONS__FABS_HPP__
-#define __STAN__AGRAD__REV__FUNCTIONS__FABS_HPP__
+#ifndef STAN__AGRAD__REV__FUNCTIONS__FABS_HPP
+#define STAN__AGRAD__REV__FUNCTIONS__FABS_HPP
 
 #include <stan/agrad/rev/var.hpp>
 #include <stan/agrad/rev/vari.hpp>
@@ -22,12 +22,31 @@ namespace stan {
      * -1 if \f$x < 0\f$, 0 if \f$x == 0\f$, and 1 if \f$x == 1\f$.
      *
      * The function <code>abs()</code> provides the same behavior, with
-     * <code>abs()</code> defined in stdlib.h and <code>fabs()</code> defined in <code>cmath</code>.
+     * <code>abs()</code> defined in stdlib.h and <code>fabs()</code> 
+     * defined in <code>cmath</code>.
      * The derivative is 0 if the input is 0.
      *
      * Returns std::numeric_limits<double>::quiet_NaN() for NaN inputs.
      *
-
+     *
+       \[		
+       \mbox{fabs}(x) = 
+       \begin{cases}
+         |x| & \mbox{if } -\infty\leq x\leq \infty \\[6pt]
+         \textrm{NaN} & \mbox{if } x = \textrm{NaN}
+       \end{cases}
+       \]
+   
+       \[
+       \frac{\partial\,\mbox{fabs}(x)}{\partial x} = 
+       \begin{cases}
+         -1 & \mbox{if } x < 0 \\
+         0 & \mbox{if } x = 0 \\
+         1 & \mbox{if } x > 0 \\[6pt]
+         \textrm{NaN} & \mbox{if } x = \textrm{NaN}
+       \end{cases}
+       \]
+     *
      * @param a Input variable.
      * @return Absolute value of variable.
      */
