@@ -1,31 +1,42 @@
-#ifndef __STAN__AGRAD__REV__MATRIX__SQUARED_DISTANCE_HPP__
-#define __STAN__AGRAD__REV__MATRIX__SQUARED_DISTANCE_HPP__
+#ifndef STAN__AGRAD__REV__MATRIX__SQUARED_DISTANCE_HPP
+#define STAN__AGRAD__REV__MATRIX__SQUARED_DISTANCE_HPP
 
 #include <vector>
-#include <stan/math/matrix/Eigen.hpp>
-#include <stan/math/matrix/typedefs.hpp>
-#include <stan/math/error_handling/matrix/check_vector.hpp>
-#include <stan/math/error_handling/matrix/check_matching_sizes.hpp>
+
 #include <stan/agrad/rev/var.hpp>
 #include <stan/agrad/rev/vari.hpp>
 #include <stan/agrad/rev/functions/sqrt.hpp>
 #include <stan/agrad/rev/matrix/typedefs.hpp>
 
+#include <stan/math/error_handling/matrix/check_vector.hpp>
+#include <stan/math/error_handling/matrix/check_matching_sizes.hpp>
+#include <stan/math/matrix/Eigen.hpp>
+#include <stan/math/matrix/typedefs.hpp>
+#include <stan/math/matrix/meta/index_type.hpp>
+#include <stan/math/meta/index_type.hpp>
+
+
 namespace stan {
+
   namespace agrad {
+
     namespace {
+
       class squared_distance_vv_vari : public vari {
       protected:
         vari** v1_;
         vari** v2_;
         size_t length_;
         
-        template<int R1,int C1,int R2,int C2>
-        inline static double var_squared_distance(const Eigen::Matrix<var,R1,C1> &v1,
-                                              const Eigen::Matrix<var,R2,C2> &v2) {
+        template <int R1,int C1,int R2,int C2>
+        inline static double 
+        var_squared_distance(const Eigen::Matrix<var,R1,C1> &v1,
+                             const Eigen::Matrix<var,R2,C2> &v2) {
+          using Eigen::Matrix;
+          using stan::math::index_type;
+          typedef typename index_type<Matrix<var,R1,R2> >::type idx_t;
           double result = 0;
-          for (typename Eigen::Matrix<var,R1,C1>::size_type i = 0;
-               i < v1.size(); i++) {
+          for (idx_t i = 0; i < v1.size(); i++) {
             double diff = v1(i).vi_->val_ - v2(i).vi_->val_;
             result += diff*diff;
           }
@@ -60,11 +71,16 @@ namespace stan {
         size_t length_;
         
         template<int R1,int C1,int R2,int C2>
-        inline static double var_squared_distance(const Eigen::Matrix<var,R1,C1> &v1,
-                                              const Eigen::Matrix<double,R2,C2> &v2) {
+        inline static double 
+        var_squared_distance(const Eigen::Matrix<var,R1,C1> &v1,
+                             const Eigen::Matrix<double,R2,C2> &v2) {
+
+          using Eigen::Matrix;
+          using stan::math::index_type;
+          typedef typename index_type<Matrix<double,R1,C1> >::type idx_t;
+
           double result = 0;
-          for (typename Eigen::Matrix<var,R1,C1>::size_type i = 0; 
-               i < v1.size(); i++) {
+          for (idx_t i = 0; i < v1.size(); i++) {
             double diff = v1(i).vi_->val_ - v2(i);
             result += diff*diff;
           }
