@@ -1,5 +1,5 @@
-#ifndef __STAN__MATH__ERROR_HANDLING__CHECK_BOUNDED_HPP__
-#define __STAN__MATH__ERROR_HANDLING__CHECK_BOUNDED_HPP__
+#ifndef STAN__MATH__ERROR_HANDLING__CHECK_BOUNDED_HPP
+#define STAN__MATH__ERROR_HANDLING__CHECK_BOUNDED_HPP
 
 #include <stan/math/error_handling/dom_err.hpp>
 #include <stan/math/error_handling/dom_err_vec.hpp>
@@ -12,9 +12,11 @@ namespace stan {
       
       // implemented using structs because there is no partial specialization
       // for templated functions
-      
+      //
       // default implementation works for scalar T_y. T_low and T_high can
       // be either scalar or vector
+      //
+      // throws if y, low, or high is nan
       template <typename T_y, typename T_low, typename T_high, typename T_result,
                 bool y_is_vec>
       struct bounded {
