@@ -1,5 +1,5 @@
-#ifndef __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_CHOLESKY_FACTOR_HPP__
-#define __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_CHOLESKY_FACTOR_HPP__
+#ifndef STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_CHOLESKY_FACTOR_HPP
+#define STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_CHOLESKY_FACTOR_HPP
 
 #include <stan/math/matrix/Eigen.hpp>
 #include <stan/math/error_handling/check_positive.hpp>
@@ -22,6 +22,7 @@ namespace stan {
      * @param name
      * @param result
      * @return <code>true</code> if the matrix is a valid Cholesky factor.
+     * @return throws if any element in matrix is nan
      * @tparam T_y Type of elements of Cholesky factor
      * @tparam T_result Type of result.
      */
