@@ -1,5 +1,5 @@
-#ifndef __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_COLUMN_INDEX_HPP__
-#define __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_COLUMN_INDEX_HPP__
+#ifndef STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_COLUMN_INDEX_HPP
+#define STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_COLUMN_INDEX_HPP
 
 #include <sstream>
 #include <stan/math/error_handling/dom_err.hpp>
@@ -11,6 +11,8 @@ namespace stan {
     /**
      * Return <code>true</code> if the specified index is a valid column of the matrix
      *
+     * NOTE: this will not throw if y contains nan values.
+     *
      * @param function
      * @param i is index
      * @param y Matrix to test against
