@@ -1,5 +1,5 @@
-#ifndef __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_LOWER_TRIANGULAR_HPP__
-#define __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_LOWER_TRIANGULAR_HPP__
+#ifndef STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_LOWER_TRIANGULAR_HPP
+#define STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_LOWER_TRIANGULAR_HPP
 
 #include <sstream>
 #include <stan/math/matrix/Eigen.hpp>
@@ -20,6 +20,7 @@ namespace stan {
      * @param name
      * @param result
      * @return <code>true</code> if the matrix is symmetric.
+     * @return throws if any element in upper triangular is nan
      * @tparam T Type of scalar.
      */
     template <typename T_y, typename T_result>
