@@ -1,5 +1,5 @@
-#ifndef __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_MATCHING_SIZES_HPP__
-#define __STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_MATCHING_SIZES_HPP__
+#ifndef STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_MATCHING_SIZES_HPP
+#define STAN__MATH__ERROR_HANDLING__MATRIX__CHECK_MATCHING_SIZES_HPP
 
 #include <stan/meta/traits.hpp>
 #include <stan/math/error_handling/dom_err.hpp>
@@ -10,6 +10,7 @@
 namespace stan {
   namespace math {
 
+    // NOTE: this will not throw if y1 or y2 contains nan values.
     template <typename T_y1, typename T_y2, typename T_result>
     inline bool check_matching_sizes(const char* function,
                                      const T_y1& y1,
