@@ -1,13 +1,14 @@
-#ifndef __STAN__MATH__MATRIX_HPP__
-#define __STAN__MATH__MATRIX_HPP__
+#ifndef STAN__MATH__MATRIX_HPP
+#define STAN__MATH__MATRIX_HPP
 
 #include <stan/math/matrix/Eigen.hpp>
 #include <stan/math/matrix/accumulator.hpp>
 #include <stan/math/matrix/add.hpp>
+#include <stan/math/matrix/append_row.hpp>
 #include <stan/math/matrix/array_builder.hpp>
 #include <stan/math/matrix/assign.hpp>
 #include <stan/math/matrix/block.hpp>
-#include <stan/math/matrix/check_range.hpp>
+#include <stan/math/matrix/append_col.hpp>
 #include <stan/math/matrix/cholesky_decompose.hpp>
 #include <stan/math/matrix/col.hpp>
 #include <stan/math/matrix/cols.hpp>
@@ -24,7 +25,6 @@
 #include <stan/math/matrix/diagonal.hpp>
 #include <stan/math/matrix/dims.hpp>
 #include <stan/math/matrix/distance.hpp>
-#include <stan/math/matrix/squared_distance.hpp>
 #include <stan/math/matrix/divide.hpp>
 #include <stan/math/matrix/dot_product.hpp>
 #include <stan/math/matrix/dot_self.hpp>
@@ -34,6 +34,7 @@
 #include <stan/math/matrix/elt_multiply.hpp>
 #include <stan/math/matrix/exp.hpp>
 #include <stan/math/matrix/fill.hpp>
+#include <stan/math/matrix/get_lp.hpp>
 #include <stan/math/matrix/get_base1.hpp>
 #include <stan/math/matrix/get_base1_lhs.hpp>
 #include <stan/math/matrix/head.hpp>
@@ -56,13 +57,17 @@
 #include <stan/math/matrix/mdivide_right_tri.hpp>
 #include <stan/math/matrix/mdivide_right_tri_low.hpp>
 #include <stan/math/matrix/mean.hpp>
+#include <stan/math/matrix/meta.hpp>
 #include <stan/math/matrix/min.hpp>
 #include <stan/math/matrix/minus.hpp>
 #include <stan/math/matrix/multiply.hpp>
 #include <stan/math/matrix/multiply_lower_tri_self_transpose.hpp>
+#include <stan/math/matrix/num_elements.hpp>
 #include <stan/math/matrix/prod.hpp>
 #include <stan/math/matrix/promote_common.hpp>
 #include <stan/math/matrix/promoter.hpp>
+#include <stan/math/matrix/promote_scalar.hpp>
+#include <stan/math/matrix/promote_scalar_type.hpp>
 #include <stan/math/matrix/qr_Q.hpp>
 #include <stan/math/matrix/qr_R.hpp>
 #include <stan/math/matrix/quad_form.hpp>
@@ -80,6 +85,7 @@
 #include <stan/math/matrix/softmax.hpp>
 #include <stan/math/matrix/sort.hpp>
 #include <stan/math/matrix/sort_indices.hpp>
+#include <stan/math/matrix/squared_distance.hpp>
 #include <stan/math/matrix/stan_print.hpp>
 #include <stan/math/matrix/sub_col.hpp>
 #include <stan/math/matrix/sub_row.hpp>
