@@ -1,9 +1,9 @@
-#ifndef __STAN__MATH__MATRIX__GET_BASE1_HPP__
-#define __STAN__MATH__MATRIX__GET_BASE1_HPP__
+#ifndef STAN__MATH__MATRIX__GET_BASE1_HPP
+#define STAN__MATH__MATRIX__GET_BASE1_HPP
 
 #include <vector>
 #include <stan/math/matrix/Eigen.hpp>
-#include <stan/math/matrix/check_range.hpp>
+#include <stan/math/error_handling/matrix/check_range.hpp>
 
 namespace stan {
   namespace math {
