@@ -1,5 +1,5 @@
-#ifndef __STAN__MATH__MATRIX__LOG_DETERMINANT_SPD_HPP__
-#define __STAN__MATH__MATRIX__LOG_DETERMINANT_SPD_HPP__
+#ifndef STAN__MATH__MATRIX__LOG_DETERMINANT_SPD_HPP
+#define STAN__MATH__MATRIX__LOG_DETERMINANT_SPD_HPP
 
 
 #include <cmath>
