@@ -1,10 +1,12 @@
-#ifndef __STAN__MATH__MATRIX__MDIVIDE_LEFT_SPD_HPP__
-#define __STAN__MATH__MATRIX__MDIVIDE_LEFT_SPD_HPP__
+#ifndef STAN__MATH__MATRIX__MDIVIDE_LEFT_SPD_HPP
+#define STAN__MATH__MATRIX__MDIVIDE_LEFT_SPD_HPP
 
 #include <boost/math/tools/promotion.hpp>
 #include <stan/math/matrix/Eigen.hpp>
 #include <stan/math/matrix/promote_common.hpp>
 #include <stan/math/error_handling/matrix/check_multiplicable.hpp>
+#include <stan/math/error_handling/matrix/check_pos_definite.hpp>
+#include <stan/math/error_handling/matrix/check_symmetric.hpp>
 #include <stan/math/error_handling/matrix/check_square.hpp>
 
 namespace stan {
@@ -23,7 +25,9 @@ namespace stan {
     inline 
     Eigen::Matrix<typename boost::math::tools::promote_args<T1,T2>::type,R1,C2>
     mdivide_left_spd(const Eigen::Matrix<T1,R1,C1> &A,
-                 const Eigen::Matrix<T2,R2,C2> &b) {
+                     const Eigen::Matrix<T2,R2,C2> &b) {
+      stan::math::check_symmetric("mdivide_left_spd(%1%)",A,"A",(double*)0);
+      stan::math::check_pos_definite("mdivide_left_spd(%1%)",A,"A",(double*)0);
       stan::math::check_square("mdivide_left_spd(%1%)",A,"A",(double*)0);
       stan::math::check_multiplicable("mdivide_left_spd(%1%)",A,"A",
                                       b,"b",(double*)0);
