@@ -1,8 +1,5 @@
-#ifndef __STAN__PROB__DISTRIBUTIONS__MULTIVARIATE__CONTINUOUS__MULTI_GP_HPP__
-#define __STAN__PROB__DISTRIBUTIONS__MULTIVARIATE__CONTINUOUS__MULTI_GP_HPP__
-
-#include <boost/random/normal_distribution.hpp>
-#include <boost/random/variate_generator.hpp>
+#ifndef STAN__PROB__DISTRIBUTIONS__MULTIVARIATE__CONTINUOUS__MULTI_GP_HPP
+#define STAN__PROB__DISTRIBUTIONS__MULTIVARIATE__CONTINUOUS__MULTI_GP_HPP
 
 #include <stan/math/matrix_error_handling.hpp>
 #include <stan/math/error_handling.hpp>
@@ -12,15 +9,11 @@
 #include <stan/agrad/rev.hpp>
 #include <stan/meta/traits.hpp>
 #include <stan/agrad/rev/matrix.hpp>
-#include <stan/math/matrix/dot_product.hpp>
 #include <stan/math/matrix/log.hpp>
 #include <stan/math/matrix/multiply.hpp>
-#include <stan/math/matrix/rows_dot_product.hpp>
-#include <stan/math/matrix/subtract.hpp>
 #include <stan/math/matrix/sum.hpp>
 
 #include <stan/math/matrix/log_determinant_ldlt.hpp>
-#include <stan/math/matrix/mdivide_right_ldlt.hpp>
 #include <stan/math/matrix/trace_gen_inv_quad_form_ldlt.hpp>
 #include <stan/math/error_handling/matrix/check_ldlt_factor.hpp>
 
@@ -48,28 +41,27 @@ namespace stan {
      */
     template <bool propto,
               typename T_y, typename T_covar, typename T_w>
-    typename boost::math::tools::promote_args<T_y,T_w,T_covar>::type
+    typename boost::math::tools::promote_args<T_y,T_covar,T_w>::type
     multi_gp_log(const Eigen::Matrix<T_y,Eigen::Dynamic,Eigen::Dynamic>& y,
                  const Eigen::Matrix<T_covar,Eigen::Dynamic,Eigen::Dynamic>& Sigma,
                  const Eigen::Matrix<T_w,Eigen::Dynamic,1>& w) {
       static const char* function = "stan::prob::multi_gp_log(%1%)";
-      typedef typename boost::math::tools::promote_args<T_y,T_w,T_covar>::type T_lp;
+      typedef typename boost::math::tools::promote_args<T_y,T_covar,T_w>::type T_lp;
       T_lp lp(0.0);
       
-      using stan::math::log;
       using stan::math::sum;
-      using stan::math::check_not_nan;
+      using stan::math::log;
+      using stan::math::LDLT_factor;
+      using stan::math::log_determinant_ldlt;
+      using stan::math::trace_gen_inv_quad_form_ldlt;
+
       using stan::math::check_size_match;
+      using stan::math::check_positive_finite;
       using stan::math::check_positive;
       using stan::math::check_finite;
       using stan::math::check_symmetric;
-      using stan::math::dot_product;
-      using stan::math::rows_dot_product;
-      using stan::math::log_determinant_ldlt;
-      using stan::math::mdivide_right_ldlt;
-      using stan::math::trace_gen_inv_quad_form_ldlt;
-      using stan::math::LDLT_factor;
       using stan::math::check_ldlt_factor;
+      using stan::math::check_not_nan;
 
       check_size_match(function, 
                        Sigma.rows(), "Rows of kernel matrix",
@@ -90,8 +82,7 @@ namespace stan {
                        y.cols(), "Size of random variable",
                        Sigma.rows(), "rows of covariance parameter",
                        &lp);
-      check_finite(function, w, "Kernel scales", &lp);
-      check_positive(function, w, "Kernel scales", &lp);
+      check_positive_finite(function, w, "Kernel scales", &lp);
       check_finite(function, y, "Random variable", &lp);
       
       if (y.rows() == 0)
@@ -102,7 +93,7 @@ namespace stan {
       }
 
       if (include_summand<propto,T_covar>::value) {
-        lp -= (0.5 * y.rows()) * log_determinant_ldlt(ldlt_Sigma);
+        lp -= 0.5 * log_determinant_ldlt(ldlt_Sigma) * y.rows();
       }
 
       if (include_summand<propto,T_w>::value) {
@@ -118,12 +109,12 @@ namespace stan {
       return lp;
     }
     
-    template <typename T_y, typename T_loc, typename T_covar>
+    template <typename T_y, typename T_covar, typename T_w>
     inline
-    typename boost::math::tools::promote_args<T_y,T_loc,T_covar>::type
+    typename boost::math::tools::promote_args<T_y,T_covar,T_w>::type
     multi_gp_log(const Eigen::Matrix<T_y,Eigen::Dynamic,Eigen::Dynamic>& y,
                  const Eigen::Matrix<T_covar,Eigen::Dynamic,Eigen::Dynamic>& Sigma,
-                 const Eigen::Matrix<T_loc,Eigen::Dynamic,1>& w) {
+                 const Eigen::Matrix<T_w,Eigen::Dynamic,1>& w) {
       return multi_gp_log<false>(y,Sigma,w);
     }
   }    
