@@ -1,5 +1,5 @@
-#ifndef __STAN__PROB__DISTRIBUTIONS__UNIVARIATE__CONTINUOUS__LOGNORMAL_HPP__
-#define __STAN__PROB__DISTRIBUTIONS__UNIVARIATE__CONTINUOUS__LOGNORMAL_HPP__
+#ifndef STAN__PROB__DISTRIBUTIONS__UNIVARIATE__CONTINUOUS__LOGNORMAL_HPP
+#define STAN__PROB__DISTRIBUTIONS__UNIVARIATE__CONTINUOUS__LOGNORMAL_HPP
 
 #include <boost/random/lognormal_distribution.hpp>
 #include <boost/random/variate_generator.hpp>
@@ -27,7 +27,7 @@ namespace stan {
       using stan::is_constant_struct;
       using stan::math::check_not_nan;
       using stan::math::check_finite;
-      using stan::math::check_positive;
+      using stan::math::check_positive_finite;
       using stan::math::check_nonnegative;      
       using stan::math::check_consistent_sizes;
       using stan::math::value_of;
@@ -47,8 +47,7 @@ namespace stan {
       check_not_nan(function, y, "Random variable", &logp);
       check_nonnegative(function, y, "Random variable", &logp);
       check_finite(function, mu, "Location parameter", &logp);
-      check_finite(function, sigma, "Scale parameter", &logp);
-      check_positive(function, sigma, "Scale parameter", &logp);
+      check_positive_finite(function, sigma, "Scale parameter", &logp);
       check_consistent_sizes(function,
                              y,mu,sigma,
                              "Random variable","Location parameter",
@@ -156,7 +155,7 @@ namespace stan {
       using stan::math::check_not_nan;
       using stan::math::check_finite;
       using stan::math::check_nonnegative;
-      using stan::math::check_positive;
+      using stan::math::check_positive_finite;
       using boost::math::tools::promote_args;
       using stan::math::value_of;
 
@@ -169,8 +168,7 @@ namespace stan {
       check_not_nan(function, y, "Random variable", &cdf);
       check_nonnegative(function, y, "Random variable", &cdf);
       check_finite(function, mu, "Location parameter", &cdf);
-      check_finite(function, sigma, "Scale parameter", &cdf);
-      check_positive(function, sigma, "Scale parameter", &cdf);
+      check_positive_finite(function, sigma, "Scale parameter", &cdf);
 
       agrad::OperandsAndPartials<T_y, T_loc, T_scale> 
         operands_and_partials(y, mu, sigma);
@@ -232,7 +230,7 @@ namespace stan {
       using stan::math::check_not_nan;
       using stan::math::check_finite;
       using stan::math::check_nonnegative;
-      using stan::math::check_positive;
+      using stan::math::check_positive_finite;
       using boost::math::tools::promote_args;
       using stan::math::value_of;
 
@@ -245,8 +243,7 @@ namespace stan {
       check_not_nan(function, y, "Random variable", &cdf_log);
       check_nonnegative(function, y, "Random variable", &cdf_log);
       check_finite(function, mu, "Location parameter", &cdf_log);
-      check_finite(function, sigma, "Scale parameter", &cdf_log);
-      check_positive(function, sigma, "Scale parameter", &cdf_log);
+      check_positive_finite(function, sigma, "Scale parameter", &cdf_log);
 
       agrad::OperandsAndPartials<T_y, T_loc, T_scale> 
         operands_and_partials(y, mu, sigma);
@@ -300,7 +297,7 @@ namespace stan {
       using stan::math::check_not_nan;
       using stan::math::check_finite;
       using stan::math::check_nonnegative;
-      using stan::math::check_positive;
+      using stan::math::check_positive_finite;
       using boost::math::tools::promote_args;
       using stan::math::value_of;
 
@@ -313,8 +310,7 @@ namespace stan {
       check_not_nan(function, y, "Random variable", &ccdf_log);
       check_nonnegative(function, y, "Random variable", &ccdf_log);
       check_finite(function, mu, "Location parameter", &ccdf_log);
-      check_finite(function, sigma, "Scale parameter", &ccdf_log);
-      check_positive(function, sigma, "Scale parameter", &ccdf_log);
+      check_positive_finite(function, sigma, "Scale parameter", &ccdf_log);
 
       agrad::OperandsAndPartials<T_y, T_loc, T_scale> 
         operands_and_partials(y, mu, sigma);
@@ -370,11 +366,10 @@ namespace stan {
       static const char* function = "stan::prob::lognormal_rng(%1%)";
 
       using stan::math::check_finite;
-      using stan::math::check_positive;
+      using stan::math::check_positive_finite;
 
       check_finite(function, mu, "Location parameter", (double*)0);
-      check_finite(function, sigma, "Scale parameter", (double*)0);
-      check_positive(function, sigma, "Scale parameter", (double*)0);
+      check_positive_finite(function, sigma, "Scale parameter", (double*)0);
 
       variate_generator<RNG&, lognormal_distribution<> >
         lognorm_rng(rng, lognormal_distribution<>(mu, sigma));
